==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/template/am_default/sn_recommended.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_groups'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($groups[0])) {
				foreach($groups as $key => $i):
				?>
			    <tr valign="top">
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="g_group.php?group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['group_synopsis'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="3">
						<?php echo $lang['err_no_groups'];?><br />
					</td>
				</tr>
				<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td colspan="3" class="txt_title" align="right">
						<?php echo $lang['hdr_topics'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($topics[0])) {
				foreach($topics as $key => $i):
				?>
				<tr valign="top">
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="g_forum_topic.php?topic_id=<?php echo $i['topic_id'];?>"><?php echo $i['topic_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['topic_body'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td colspan="3">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td colspan="3">
						<?php echo $lang['err_no_topics'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_subjects'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($subjects[0])) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<a href="g_forum_subject.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['subject_body'];?></span><br />
					</td>
			    </tr>

				<?if (isset($i['poll'][0])) {?>
				<tr>
					<td align="right">
						<?php
						include $templatePath . "poll.inc.tpl.php";
						?>
					</td>
				</tr>
				<?php
				}
				?>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_subjects'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_library'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($library[0])) {
				foreach($library as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="g_library.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['library_synopsis']);?></span><br />
					</td>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_events'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($events[0])) {
				foreach($events as $key => $i):
				?>
			    <tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_image.php?img=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="sn_event.php?event_id=<?php echo $i['event_id'];?>"><?php echo $i['event_title'];?></a><br />
						<?php echo $i['event_start_datetime'];?><br />
						<span class="txt_footer"><?php echo $i['event_description'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_events'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_blogs'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs[0])) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<?php echo $i['user_nic'];?>: <?php echo $i['blog_create_datetime'];?><br />
						<span class="txt_footer">
						<a href="sn_blog.php?user_id=<?php echo $user['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
						<?php echo $i['blog_synopsis'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blogs'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_statistics'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<table cellpadding="4" cellspacing="0" border="0" width="100%">
							<tr>
								<td>
									<?php echo $lang['txt_statistic_group'];?><br />
								</td>
								<td align="right">
									<?php
									$total = 0;
									if (isset($groups)) {
									    print count($groups);
										$total = $total+count($groups);
									}
									?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_statistic_forum'];?><br />
								</td>
								<td align="right">
									<?php
									$forum = 0;
									if (isset($topics)) {
									    $forum = count($topics);
									}
									if (isset($subjects)) {
									    $forum = $forum + count($subjects);
										print $forum;
										$total = $total+$forum;
									}
									?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_statistic_library'];?><br />
								</td>
								<td align="right">
									<?php
									if (isset($library)) {
									    print count($library);
										$total = $total+count($library);
									}
									?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_statistic_blog'];?><br />
								</td>
								<td align="right">
									<?php
									if (isset($blogs)) {
									    print count($blogs);
										$total = $total+count($blogs);
									}
									?><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $lang['txt_statistic_event'];?><br />
								</td>
								<td align="right">
									<?php
									if (isset($events)) {
									    print count($events);
										$total = $total+count($events);
									}
									?><br />
								</td>
							</tr>
							<tr>
								<td>
									&nbsp;
								</td>
								<td align="right">
									<?php echo $total;?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</table>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/sn_recommended.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "sn_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_subjects'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<a href="g_forum_subject.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
						<span class="txt_footer"><?php echo $i['subject_body'];?></span><br />
					</td>
			    </tr>

				<?if (!empty($i['poll'])) {?>
				<tr>
					<td align="right">
						<?php
						include $templatePath . "poll.inc.tpl.php";
						?>
					</td>
				</tr>
				<?php
				}
				?>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_subjects'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_library'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($library)) {
				foreach($library as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_file.php?file=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="g_library.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
						<span class="txt_footer"><?php echo dots('120', $i['library_synopsis']);?></span><br />
					</td>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_library'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_activities'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($events)) {
				foreach($events as $key => $i):
				?>
			    <tr>
					<td>
						<?php
						if (isset($i['image']['image_id'])) {
						?>
							<img align="left" src="get_file.php?file=<?php echo $i['image']['image'];?>" border="0" class="picture" title="<?php echo $i['image']['image_title'];?>" alt="" /><br />
						<?
						}
						?>
						<a href="sn_event.php?event_id=<?php echo $i['event_id'];?>"><?php echo $i['event_title'];?></a><br />
						<?php echo $i['event_start_datetime'];?><br />
						<span class="txt_footer"><?php echo $i['event_synopsis'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_events'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['hdr_blogs'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<?php echo $i['user_nic'];?>: <?php echo $i['blog_create_datetime'];?><br />
						<span class="txt_footer">
						<a href="sn_blog.php?user_id=<?php echo $user['user_id'];?>&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
						<?php echo $i['blog_synopsis'];?></span><br />
					</td>
			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
					</td>
				</tr>
			<?php
				endforeach;
				} else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blogs'];?><br />
					</td>
				</tr>
			<?php }?>
			</table>
		</td>
	</tr>
</table>
